==> ocstore25_6_20.zip: OcStore/Prgm/data/language/en-us/script/CS_village_around.lua <==
function E0090()
    InitRoom()FAI(0)
end
function E0091()
    InitRoom()FAI(1)
end
function E0092()
    InitRoom()FAI(2)
end
function E0093()
    InitRoom()FAI(3)
end
function E0094()
    InitRoom()FAI(4)
end

function InitRoom()
    MNA()
    if(FLJ("KingBack")) then
        CMU("CS_Quiet")
    else
        CMU("CS_Mura")
    end
end

function GoVillage()
    PRI()FAO(3)TRA("CS_village","E0091",58,12,1,12)
end

function GoCrossRoads()
    if(FLJ("KingBack")) then
        PRI()FAO(1)TRA("CS_crossroads2","E0093",1,14,1,9)
    else
        PRI()FAO(1)TRA("CS_crossroads","E0093",1,14,1,9)
    end
end

--游戏起始事件
function GameStart()
    KEY()
    CMU("XXXX")
    MS2("This English localization is work-in-progress,")
    CAT("\nrevised version will be uploaded soon,")NOD()
    CAT("\nthank you for your patience.")NOD()CLO()
    WAI(64)
    --创建实体
    SNP("null",51,12,0,"mainLayer","Camera1")
    SNP("CS_mychar_kanpa_animate",47,13,0,"mainLayer","Kanpa1")
    SNP("CS_bucket",48,13,0,"mainLayer","Bucket1")
    SNP("CS_enemy_chinfish",42,17,1,"mainLayer","")
    DNP("SavePoint")
    FON("Camera1",0)
    MOV(47,13)
    --间八钓鱼
    ANP("Kanpa1",200,0)--显示鱼竿
    ANP("Kanpa1",3,0)--坐着
    ANP("Kanpa1",203,0)--闭上眼
    CMU("CS_Mura")
    FAI(4)
    WAI(64)
    ANP("Kanpa1",202,0)--睁开眼
    WAI(32)
    MS3("That's plenty of fish for today.")NOD()
    CAT("\nTime to go home~")NOD()CLO()
    ITP("Chinfish")
    MSA("AskEveryoneAboutMahin")
    WAI(16)
    ANP("Kanpa1",0,0)--站起
    WAI(32)
    FAO(0)
    --切换房间
    TRA("CS_kanpa_house","KanpaBackHome",14,14)
end

--钓鱼
function Fishing1()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("It's a chinfish commonly") 
        CAT("\nfound in the village pond...")NOD()CLR()
        ITP("Chinfish")
        GIT("Chinfish")
        SOU("CS_038_get_item")
        DNP("Fishing1")
        FLP("Fishing1")
        CMU("CS_Fanfale1")
        CAT("\nGot a =CHINFISH=.")WAI(160)NOD()
        RMU()
    end
end

function SueAndTorokoLookForCat()
    KEY()
    CMU("CS_Mura")
    SNP("CS_sue_animate",64,9,0,"mainLayer","Sue1")--数
    ANP("Sue1","back",0)
    SNP("CS_toroko_animate",49,13,1,"mainLayer","Toroko1")--多隆子
    ANP("Toroko1","normal",1)
    FAI(2)
    WAI(32)
    FAC("sue_normal")MS3("This is where I saw the")
    CAT("\nbig cat before,")NOD()
    ANP("Sue1","normal",0)
    FAC("sue_sad")CAT("\nbut it's not here now...")NOD()CLR()
    FAC("toroko_normal")CAT("Maybe Mr. Cat isn't awake") 
    CAT("\nat this hour...")NOD()CLO()
    CMU("XXXX")
    QUA(30)
    MS3("?")NOD()CLO()
    SNP("CS_puu_animate",66,-2,0,"mainLayer","Puu1")--Puu
    ANP("Puu1","dark")
    ANP("Puu1",1060,0)
    WAI(64)
    ANP("Sue1","normal",1)
    WAI(32)
    ANP("Sue1","hurt_down",1)
    WAI(32)
    FAC("toroko_><")MS3("\nSue!!")NOD()CLR()
    FAC("sue_hurt")CAT("There's a monster!!")NOD()
    CAT("\nRun, Toroko!!")NOD()CLO()
    CMU("CS_Escape")
    ANP("Puu1","open_mouth")
    WAI(16)
    SNP("CS_bubble_catcher",66,9,0,"mainLayer","Bubble1")
    SOU("CS_021_bubble")
    ANP("Bubble1","set_target")
    ANP("Bubble1","Toroko1")
    --多隆子逃跑
    FON("Toroko1")
    ANP("Toroko1","run",0)
    ANP("Toroko1","jump",0)
    WAI(16)
    ANP("Puu1","normal")
    WAI(24)
    ANP("Toroko1","big_jump",0)
    WAI(52)
    ANP("Toroko1","big_jump",0)
    WAI(40)
    ANP("Toroko1","big_jump",0)
    WAI(300)
    ANP("Bubble1","top_draw_false")
    FAO(3)
    TRA("CS_village","TorokoHasBeenCaptured",46,11)
end

==> ocstore25_7_4.zip: OcStore/Prgm/data/language/en-us/script/CS_village_around.lua <==
function E0090()
    InitRoom()FAI(0)
end
function E0091()
    InitRoom()FAI(1)
end
function E0092()
    InitRoom()FAI(2)
end
function E0093()
    InitRoom()FAI(3)
end
function E0094()
    InitRoom()FAI(4)
end

function InitRoom()
    MNA()
    if(FLJ("KingBack")) then
        CMU("CS_Quiet")
    else
        CMU("CS_Mura")
    end
end

function GoVillage()
    PRI()FAO(3)TRA("CS_village","E0091",58,12,1,12)
end

function GoCrossRoads()
    if(FLJ("KingBack")) then
        PRI()FAO(1)TRA("CS_crossroads2","E0093",1,14,1,9)
    else
        PRI()FAO(1)TRA("CS_crossroads","E0093",1,14,1,9)
    end
end

--游戏起始事件
function GameStart()
    KEY()
    CMU("XXXX")
    MS2("This English localization is work-in-progress,")
    CAT("\nrevised version will be uploaded soon,")NOD()
    CAT("\nthank you for your patience.")NOD()CLO()
    WAI(64)
    --创建实体
    SNP("null",51,12,0,"mainLayer","Camera1")
    SNP("CS_mychar_kanpa_animate",47,13,0,"mainLayer","Kanpa1")
    SNP("CS_bucket",48,13,0,"mainLayer","Bucket1")
    SNP("CS_enemy_chinfish",42,17,1,"mainLayer","")
    DNP("SavePoint")
    FON("Camera1",0)
    MOV(47,13)
    --间八钓鱼
    ANP("Kanpa1",200,0)--显示鱼竿
    ANP("Kanpa1",3,0)--坐着
    ANP("Kanpa1",203,0)--闭上眼
    CMU("CS_Mura")
    FAI(4)
    WAI(64)
    ANP("Kanpa1",202,0)--睁开眼
    WAI(32)
    MS3("That's plenty of fish for today.")NOD()
    CAT("\nTime to go home~")NOD()CLO()
    ITP("Chinfish")
    MSA("AskEveryoneAboutMahin")
    WAI(16)
    ANP("Kanpa1",0,0)--站起
    WAI(32)
    FAO(0)
    --切换房间
    TRA("CS_kanpa_house","KanpaBackHome",14,14)
end

--钓鱼
function Fishing1()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("It's a chinfish commonly") 
        CAT("\nfound in the village pond...")NOD()CLR()
        ITP("Chinfish")
        GIT("Chinfish")
        SOU("CS_038_get_item")
        DNP("Fishing1")
        FLP("Fishing1")
        CMU("CS_Fanfale1")
        CAT("\nGot a =CHINFISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end

--钓鱼（普通模式）
function Fishing1_Normal()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("It's a chinfish commonly") 
        CAT("\nfound in the village pond...")NOD()CLR()
        ITP("Chinfish")
        GIT("Chinfish")
        SOU("CS_038_get_item")
        DNP("Fishing1_Normal")
        FLP("Fishing1_Normal")
        CMU("CS_Fanfale1")
        CAT("\nGot a =CHINFISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end

--钓鱼（普通模式）
function Fishing2_Normal()
    PRI()
    if(WET()) then
        MS4("The fish is still thrashing") 
        CAT("\nabout in the water,")NOD()
        CAT("\nmaking it difficult to catch.")NOD()
    else
        MS4("It's a chinfish commonly") 
        CAT("\nfound in the village pond...")NOD()CLR()
        ITP("Chinfish")
        GIT("Chinfish")
        SOU("CS_038_get_item")
        DNP("Fishing2_Normal")
        FLP("Fishing2_Normal")
        CMU("CS_Fanfale1")
        CAT("\nGot a =CHINFISH=.")WAI(160)NOD()
        RMU()
        KanpaEatFishDesc()
    end
end

function SueAndTorokoLookForCat()
    KEY()
    CMU("CS_Mura")
    SNP("CS_sue_animate",64,9,0,"mainLayer","Sue1")--数
    ANP("Sue1","back",0)
    SNP("CS_toroko_animate",49,13,1,"mainLayer","Toroko1")--多隆子
    ANP("Toroko1","normal",1)
    FAI(2)
    WAI(32)
    FAC("sue_normal")MS3("This is where I saw the")
    CAT("\nbig cat before,")NOD()
    ANP("Sue1","normal",0)
    FAC("sue_sad")CAT("\nbut it's not here now...")NOD()CLR()
    FAC("toroko_normal")CAT("Maybe Mr. Cat isn't awake") 
    CAT("\nat this hour...")NOD()CLO()
    CMU("XXXX")
    QUA(30)
    MS3("?")NOD()CLO()
    SNP("CS_puu_animate",66,-2,0,"mainLayer","Puu1")--Puu
    ANP("Puu1","dark")
    ANP("Puu1",1060,0)
    WAI(64)
    ANP("Sue1","normal",1)
    WAI(32)
    ANP("Sue1","hurt_down",1)
    WAI(32)
    FAC("toroko_><")MS3("\nSue!!")NOD()CLR()
    FAC("sue_hurt")CAT("There's a monster!!")NOD()
    CAT("\nRun, Toroko!!")NOD()CLO()
    CMU("CS_Escape")
    ANP("Puu1","open_mouth")
    WAI(16)
    SNP("CS_bubble_catcher",66,9,0,"mainLayer","Bubble1")
    SOU("CS_021_bubble")
    ANP("Bubble1","set_target")
    ANP("Bubble1","Toroko1")
    --多隆子逃跑
    FON("Toroko1")
    ANP("Toroko1","run",0)
    ANP("Toroko1","jump",0)
    WAI(16)
    ANP("Puu1","normal")
    WAI(24)
    ANP("Toroko1","big_jump",0)
    WAI(52)
    ANP("Toroko1","big_jump",0)
    WAI(40)
    ANP("Toroko1","big_jump",0)
    WAI(300)
    ANP("Bubble1","top_draw_false")
    FAO(3)
    TRA("CS_village","TorokoHasBeenCaptured",46,11)
end
